# Huanzhi_Utils

This is a utils library that I often use in my project. I'm lazy and I don't want to copy and paste the same code to every project, so I decided to create this library. I will keep updating it as I develop more projects.
